The ISO 28258 domain model {#sec:28258}
=======================================

## Overview

The international standard "Soil quality - Digital exchange of soil-related
data" (ISO number 28258) [@ISO-28258] is the result of a joint effort by the
ISO technical committee "Soil quality" and the technical committee "Soil
characterisation" of the European Committee for Standardisation (CEN).
Recognising a growing need to combine soil data with other types of data -
especially environmental - these committees set out to produce a general
framework for the unambiguous recording and exchange of soil data, consistent
with other international standards and independent of particular software
systems.

The ISO 28258 standard was from the onset developed to target an XML based
implementation. Its goal was not necessarily to attain a common understanding
of the domain, rather to design a digital soil data exchange infrastructure.
Therefore the accompanying UML domain model on which the XML exchange schema is
rooted was merely a means to an end. Also recognising the relevance of spatial
positioning in soil data, the standard adopted the Geography Markup Language
(GML) as a geo-spatial extension to the XML encoding.

Even though not necessarily focused on a domain model, ISO 28258 captures a
relatively wide range of concepts from soil surveying and physio-chemical
analysis. The domain model is a direct application of the meta-model proposed 
in the Observations and Measurements (O&M) standard [@ISO-19156] to the soil
domain. It aims to support both analytical and descriptive results.  

ISO 28258 identifies the following features of interest:


  - `Site` - representing the surrounding environment
    of a soil investigation, the subject of observations such as terrain or land
    use.
  - `Plot` - the location or spatial feature where a soil
    investigation is conducted, usually leading to a soil profile description
    and/or to the collection of soil material for physio-chemical analysis.
    `Plot` is further specialised into `Surface`, `TrialPit` and
    `Borehole`.
  - `Profile` - an ordered set of soil
    horizons or layers comprising the soil pedon at a specific spatial
    location. The object of soil classification.
  - `ProfileElement` - an element of a soil profile, characterised by an upper and lower depth.
    Specialised into `Horizon` - a pedo-genetically homogeneous segment
    of the soil profile - and `Layer` - an arbitrary and heterogeneous
    segment of the soil profile.
  - `SoilSpecimen` - an homogenised
    sample of soil material collected at a specific soil depth. Usually meant
    for physio-chemical analysis.

[Figure @fig:iso:simple] presents a simplified diagram of the ISO 28258 domain model showing the
relevant relations between features of interest.

![Simplified UML class diagram with ISO 28258 features of interest.](diagrams/iso-28258.png){#fig:iso:simple}

Meant as an asset for global use, ISO 28258 did not went into further
specialisation. It does not propose attribute catalogues, vocabularies or
code-lists of any kind, remaining open to the different soil description and
classification systems used around the world. Although specifying a class for
the traditional concept of "mapping soil unit" used in vector based soil
mapping, the standard does not actually support the raster data paradigm.
ISO 28258 was conceived as an empty container, to be subject of further
specialisation for the actual encoding of soil data (possibly at regional or
national scale). However, the standard has so far never been applied in this
context it was designed for. The combination of a XML/GML approach (for which
off-the-shelf tools remain scant) with the lack of code-lists possibly made the
outright adoption of this standard too abstract for soil data providers.

## Relation with other soil ontologies {#sec:28258:relation}

The ISO 28258 domain model is semantically rooted in O&M  (see [Section @sec:om]
for details), re-using UML stereotypes from that standard throughout. This
architecture automatically aligns ISO 28258 with other standards from ISO and
the OGC, such as Sampling Features. Moreover, it also provides alignment with
other soil ontologies that follow a similar philosophy.

### INSPIRE Soil Theme

Perhaps the most relevant among the domain models related to ISO 28258 is the
Soil Theme domain model published by the European Commission in the context of
the INSPIRE directive [@INSPIRE-Soil]. The core of these two models, concerning
the abstraction of observations and measurements is by and large the same, with
the concept of `Observation` expressed as a triple: `Property`, `Procedure` and
`Unit`. As for the features of interest there are differences mainly in how the
spatial surrounding of a soil investigation is abstracted.  The concepts of
`Plot` and `Site` are also present in INSPIRE but in a leaner way, without the
specialisations found in ISO 28258. INSPIRE further adds the concept of
`SoilBody`, a wider spatial area in which various soil investigations are
conducted. And the concepts of `RectifiedGridCoverage` and
`ReferenceableGridCoverage` provide a back-bone for gridded data. 

### OGC SoilIE

In 2016 the OGC hosted an initiative named Soil Interoperability Experiment
(SoilIE) [@OGC-SoilIE] with similar goals to those of ISO 28258. Also
focused on data exchange, SoilIE would go into far more detail concerning
features of interest. The resulting domain model is sub-divided into four
sub-models, each addressing a specific aspect of soil information: (i) soil
classification; (ii) soil profile description; (iii) sampling and
field/laboratory observations; and (iv) sensor-based monitoring of dynamic soil
properties. Left out of the experiment were soil mapping and landscape/land-use
characterisation. 

The SoilIE domain model yields familiar concepts such as `Site`, `Plot`,
`Soil`, `Layer`, `Horizon` or `Sample`. But these are complemented by many other
classes, in what is a far broader set of features of interest, with more intricate
relationships. However, to what observations and measures is concerned, the same
patterns proposed in the O\&M standard are applied in this domain model too. 

### GloSIS

The GloSIS web ontology is essentially a translation of the ISO 28258 domain
model to the Semantic Web, employing the Ontology Web Language (OWL). While
semantically it is the same model, GloSIS introduces large sets of ready to use
code-lists, including:

- Descriptive properties values (transposed from the FAO Guidelines of Soil
  Description [@Jahn2006]).

- Physio-chemical properties (for Layer, Horizon, Plot and Profile).

- Procedures associated with physio-chemical properties (re-used from the Africa Soil
  Profiles project [@Leenaars2014]).

By adopting the Semantic Web paradigm, this ontology automatically expresses
all its content with Universal Resource Identifiers (URIs), than can easily be
rendered dereferencable with a service such as W3ID [@w3id]. The GloSIS web
ontology has in this way become one of the most extensive resources on soil
ontology on the web.

## Issues identified

During the course of this work various issues were identified with the ISO
domain model that required addressing in the adaptation to the Soils4Africa
project. In particular:


1. The `Surface` and `Site` concepts revealed too similar and difficult to
   distinguish by soil scientists. Although yielding slightly different
   properties, the domain model is not fully clear. Moreover, a polygon type of
   spatial feature is expected to have a one-to-one relation with a `Profile`.

2. The `SoilSpecimen` concept is defined with a single depth property, whereas
   in soil surveying a sample collected in the field is always reported with
   two depths (upper and lower boundaries). A specimen (or sample) is regarded
   as a tangible segment of the soil profile whose material is homogenised.

3. `SoilSpecimen` and `Layer` appear also as too similar concepts. Both report
   to an arbitrary segment or stratum of the soil profile, in most cases
   unrelated to pedo-genetic horizon boundaries. Moreover, soil properties
   assessed in laboratories from soil specimens are often reported in
   reference to a soil layer by data providers. The depth
   issue noted above blurs the distinction between the two concepts
   even further.


















